@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Base;
 
-our $DATE = '2015-11-29'; # DATE
-our $VERSION = '1.41'; # VERSION
+our $DATE = '2015-12-02'; # DATE
+our $VERSION = '1.42'; # VERSION
 
 use 5.010001;
 use strict;
@@ -274,18 +274,25 @@ _
             return [] unless $r->{config};
 
             my @profiles;
-            for (keys %{$r->{config}}) {
-                if (length $r->{subcommand_name}) {
-                    push @profiles, $1
-                        if /\A\Q$r->{subcommand_name}\E \s+ profile=(.+)/x;
-                } else {
-                    push @profiles, $1 if /\Aprofile=(.+)/;
+            for my $section (keys %{$r->{config}}) {
+                my %keyvals;
+                $section = '' if $section eq 'GLOBAL';
+                for my $word (split /\s+/, $section) {
+                    if ($word =~ /(.+)=(.*)/) {
+                        $keyvals{$1} = $2;
+                    } else {
+                        # old syntax, will be removed sometime in the future
+                        $keyvals{subcommand} = $word;
+                    }
+                }
+                if (defined(my $p = $keyvals{profile})) {
+                    push @profiles, $p unless grep {$_ eq $p} @profiles;
                 }
             }
 
             require Complete::Util;
             Complete::Util::complete_array_elem(
-                array=>[sort @profiles], word=>$word, ci=>1);
+                array=>\@profiles, word=>$word, ci=>1);
         },
         tags => ['category:configuration'],
     },
@@ -1404,7 +1411,7 @@ Perinci::CmdLine::Base - Base class for Perinci::CmdLine{::Classic,::Lite}
 
 =head1 VERSION
 
-This document describes version 1.41 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2015-11-29.
+This document describes version 1.42 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2015-12-02.
 
 =head1 DESCRIPTION
 
