@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Util::Config;
 
-our $DATE = '2015-11-29'; # DATE
-our $VERSION = '1.41'; # VERSION
+our $DATE = '2015-12-02'; # DATE
+our $VERSION = '1.42'; # VERSION
 
 use 5.010;
 use strict;
@@ -110,29 +110,28 @@ sub get_args_from_config {
 
     my %seen_profiles; # for debugging message
     for my $section (@sections) {
-        my ($sect_scn, $sect_profile);
-        if ($section =~ /\Aprofile=(.*)\z/) {
-            $sect_scn = 'GLOBAL';
-            $sect_profile = $1;
-        } elsif ($section =~ /\A\S+\z/) {
-            $sect_scn = $section;
-        } elsif ($section =~ /\A(\S+)\s+profile=(.*)\z/) {
-            $sect_scn = $1;
-            $sect_profile = $2;
-        } else {
-            die [412, "Error in config file: invalid section name ".
-                     "'$section', please use subcommand name + optional ".
-                         "' profile=PROFILE' only"];
+        my %keyvals;
+        for my $word (split /\s+/, ($section eq 'GLOBAL' ? '' : $section)) {
+            if ($word =~ /(.+)=(.*)/) {
+                $keyvals{$1} = $2;
+            } else {
+                # old syntax, will be removed sometime in the future
+                $keyvals{subcommand} = $word;
+            }
         }
-        $seen_profiles{$sect_profile}++ if defined $sect_profile;
+        $seen_profiles{$keyvals{profile}}++ if defined $keyvals{profile};
+
+        my $sect_scn     = $keyvals{subcommand} // '';
+        my $sect_profile = $keyvals{profile};
+
         if (length $scn) {
-            next if $sect_scn ne 'GLOBAL' && $sect_scn ne $scn;
+            next if length($sect_scn) && $sect_scn ne $scn;
         } else {
-            next if $sect_scn ne 'GLOBAL';
+            next if length $sect_scn;
         }
         if (defined $profile) {
             next if defined($sect_profile) && $sect_profile ne $profile;
-            $found++ if defined($sect_profile) && $sect_profile eq $profile;
+            $found = 1 if defined($sect_profile) && $sect_profile eq $profile;
         } else {
             next if defined($sect_profile);
         }
@@ -192,7 +191,7 @@ Perinci::CmdLine::Util::Config - Utility routines related to config files
 
 =head1 VERSION
 
-This document describes version 1.41 of Perinci::CmdLine::Util::Config (from Perl distribution Perinci-CmdLine-Lite), released on 2015-11-29.
+This document describes version 1.42 of Perinci::CmdLine::Util::Config (from Perl distribution Perinci-CmdLine-Lite), released on 2015-12-02.
 
 =head1 FUNCTIONS
 
